from vkbottle.api import UserApi
from vkbottle.rule import FromMe
from vkbottle.user import Blueprint, Message

from idm_lp.logger import logger_decorator
from idm_lp.database import Database, IgnoredMembers
from idm_lp.utils import edit_message, get_ids_by_message, get_full_name_by_member_id, generate_user_or_groups_list, \
    get_link, get_push_by_id

user = Blueprint(
    name='ignored_members_blueprint'
)


def add_ignore_member(database: Database, member_id: int, peer_id: int) -> None:
    database.ignored_members.append(
        IgnoredMembers(
            member_id=member_id,
            chat_id=peer_id
        )
    )
    database.save()


def remove_ignore_member(database: Database, member_id: int, peer_id: int) -> None:
    ignored_member = None
    for ign in database.ignored_members:
        if ign.member_id == member_id and ign.chat_id == peer_id:
            ignored_member = ign
    database.ignored_members.remove(ignored_member)
    database.save()


async def show_ignore_members(
        database: Database,
        api: UserApi,
        peer_id: int
) -> str:
    user_ids = [
        ignore_member.member_id
        for ignore_member in database.ignored_members
        if ignore_member.chat_id == peer_id and ignore_member.member_id > 0
    ]
    group_ids = [
        abs(ignore_member.member_id)
        for ignore_member in database.ignored_members
        if ignore_member.chat_id == peer_id and ignore_member.member_id < 0
    ]

    if not user_ids and not group_ids:
        return "📃 Ваш игнор-лист пуст"

    message = "📃 Ваш игнор-лист для этого чата:\n"
    return await generate_user_or_groups_list(api, message, user_ids, group_ids)


@user.on.message_handler(
    FromMe(),
    text=[
        '<prefix:service_prefix> +игнор [id<user_id:int>|<foo>',
        '<prefix:service_prefix> +игнор [club<group_id:int>|<foo>',
        '<prefix:service_prefix> +игнор https://vk.com/<domain>',
        '<prefix:service_prefix> +игнор',
    ]
)
@logger_decorator
async def add_ignored_member_wrapper(
        message: Message,
        domain: str = None,
        user_id: int = None,
        group_id: int = None,
        **kwargs
):
    db = Database.get_current()
    member_id = user_id if user_id else None
    if not user_id and group_id:
        member_id = -group_id

    member_ids = await get_ids_by_message(message, member_id, domain)
    if not member_ids:
        await edit_message(
            message,
            f'⚠ Необходимо указать пользователей'
        )
        return

    member_id = member_ids[0]
    if member_id == await message.api.user_id:
        await edit_message(
            message,
            f'⚠ Нельзя занести себя в игнор!'
        )
        return

    if member_id > 0:
        name = f'Пользователь  [id{member_id}|{await get_full_name_by_member_id(message.api, member_id)}]'
    else:
        name = f'Группа [club{abs(member_id)}|{await get_full_name_by_member_id(message.api, member_id)}]'

    if member_id in [
        igrored_member.member_id
        for igrored_member in db.ignored_members
        if igrored_member.chat_id == message.peer_id
    ]:
        await edit_message(
            message,
            f'⚠ {name} уже в списке игнорируемых'
        )
        return
    add_ignore_member(db, member_id, message.peer_id)
    await edit_message(
        message,
        f'✅ {name} добавлен в игнор-лист'
    )


@user.on.message_handler(
    FromMe(),
    text=[
        '<prefix:service_prefix> -игнор [id<user_id:int>|<foo>',
        '<prefix:service_prefix> -игнор [club<group_id:int>|<foo>',
        '<prefix:service_prefix> -игнор https://vk.com/<domain>',
        '<prefix:service_prefix> -игнор',
    ]
)
@logger_decorator
async def remove_ignored_member_wrapper(
        message: Message,
        domain: str = None,
        user_id: int = None,
        group_id: int = None,
        **kwargs
):
    db = Database.get_current()
    member_id = user_id if user_id else None
    if not user_id and group_id:
        member_id = -group_id

    member_ids = await get_ids_by_message(message, member_id, domain)
    if not member_ids:
        await edit_message(
            message,
            f'⚠ Необходимо указать пользователей'
        )
        return

    member_id = member_ids[0]

    if member_id > 0:
        name = f'Пользователь  [id{member_id}|{await get_full_name_by_member_id(message.api, member_id)}]'
    else:
        name = f'Группа [club{abs(member_id)}|{await get_full_name_by_member_id(message.api, member_id)}]'

    if member_id not in [
        igrored_member.member_id
        for igrored_member in db.ignored_members
        if igrored_member.chat_id == message.peer_id
    ]:
        await edit_message(
            message,
            f'⚠ {name} не в списке игнорируемых'
        )
        return
    remove_ignore_member(db, member_id, message.peer_id)
    await edit_message(
        message,
        f'✅ {name} удален из игнор-листа'
    )


@user.on.message_handler(
    FromMe(),
    text=[
        '<prefix:service_prefix> игнорлист',
        '<prefix:service_prefix> игнор лист',
    ]
)
@logger_decorator
async def show_ignore_members_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    await edit_message(
        message,
        await show_ignore_members(
            db,
            message.api,
            message.peer_id
        )
    )


@user.on.message_handler(
    FromMe(),
    text=[
        '<prefix:service_prefix> игнорлист все',
        '<prefix:service_prefix> игнор лист все',
    ]
)
@logger_decorator
async def show_all_ignore_members_wrapper(message: Message, **kwargs):
    db = Database.get_current()

    user_ids = [
        ignore_member.member_id
        for ignore_member in db.ignored_members
        if ignore_member.member_id > 0 and ignore_member.chat_id is not None
    ]
    group_ids = [
        abs(ignore_member.member_id)
        for ignore_member in db.ignored_members
        if ignore_member.member_id < 0 and ignore_member.chat_id is not None
    ]

    if not user_ids and not group_ids:
        return "📃 Ваш игнор-лист пуст"
    users = await message.api.users.get(user_ids=user_ids) if user_ids else []
    groups = await message.api.groups.get_by_id(group_ids=group_ids) if group_ids else []

    ignored = {}
    for _ignored in [x for x in db.ignored_members if x.chat_id is not None]:
        ignored.setdefault(_ignored.chat_id, [])
        ignored[_ignored.chat_id] += [_ignored]

    text = "📃 Ваш игнор-лист по всем чатам:\n"

    for k in ignored.keys():
        text += f"\n{get_link(k)}\n"
        index = 1
        for member in ignored[k]:
            text += f"{index}. {get_push_by_id(users, groups, member.member_id)}\n"
            index += 1
    await edit_message(
        message, text
    )



import json

from vkbottle.user import Blueprint, Message

from idm_lp.idm_api import IDMAPI, IDMException
from idm_lp.logger import logger_decorator

user = Blueprint(
    name='duty_signal_blueprint'
)


# noinspection DuplicatedCode
async def send_signal(
        message: Message,
        prefix: str,
        signal: str
):
    try:
        await IDMAPI.get_current().send_signal(
            from_id=message.from_id, peer_id=message.peer_id,
            conversation_message_id=message.conversation_message_id,
            date=message.date, text=prefix + ' ' + signal, vk_message=json.loads(message.json())
        )
    except IDMException as ex:
        await message.api.messages.send(
            random_id=0,
            peer_id=await message.api.user_id,
            message=f"[IDM LP]\n⚠ Произошла ошибка при отправке сигнала на сервер IDM:\n💬 {ex}"
        )


@user.on.message_handler(text='<prefix:duty_prefix> [id<user_id:int>|<name>] <signal>')
@logger_decorator
async def duty_signal(message: Message, prefix: str, user_id: int, signal: str, **kwargs):
    if user_id != await message.api.user_id:
        return
    await send_signal(message, prefix, signal)


@user.on.message_handler(text='<prefix:duty_prefix> <signal>')
@logger_decorator
async def duty_signal(message: Message, prefix: str, signal: str, **kwargs):
    user_ids = []
    if message.reply_message:
        user_ids.append(message.reply_message.from_id)
    for fwd in message.fwd_messages:
        user_ids.append(fwd.from_id)

    if await message.api.user_id not in user_ids:
        return

    await send_signal(message, prefix, signal)



import typing

from pydantic import BaseModel, validator

__all__ = (
    'IgnoredMembers',
    'MutedMembers',
)


class IgnoredMembers(BaseModel):
    member_id: int
    chat_id: typing.Optional[int]


class MutedMembers(BaseModel):
    member_id: int
    chat_id: int
    delay: int = 0

    @validator('delay')
    def positive_int_validator(cls, v: int) -> int:
        return int(v) if v > 0 else 0



from vkbottle.api import API

from idm_lp.database import Database, Timer


async def auto_infection_timer(api: API, db: Database):
    await api.messages.send(
        peer_id=db.auto_infection_peer_id,
        message=f"заразить {db.auto_infection_argument}",
        random_id=0,
    )


async def send_message_timer(api: API, db: Database, timer: Timer):
    await api.messages.send(
        peer_id=timer.peer_id,
        attachment=timer.message_attachment,
        message=timer.message_text,
        random_id=0
    )



from vkbottle.api import UserApi
from vkbottle.rule import FromMe
from vkbottle.user import Blueprint, Message

from idm_lp.logger import logger_decorator
from idm_lp.database import Database, IgnoredMembers
from idm_lp.utils import edit_message, get_ids_by_message, get_full_name_by_member_id, generate_user_or_groups_list

user = Blueprint(
    name='ignored_global_members_blueprint'
)


def add_ignore_global_member(database: Database, member_id: int) -> None:
    database.ignored_members.append(
        IgnoredMembers(
            member_id=member_id,
            chat_id=None
        )
    )
    database.save()


def remove_ignore_global_member(database: Database, member_id: int) -> None:
    ignored_member = None
    for ign in database.ignored_global_members:
        if ign.member_id == member_id:
            ignored_member = ign
    database.ignored_members.remove(ignored_member)
    database.save()


async def show_ignore_global_members(
        database: Database,
        api: UserApi
) -> str:
    user_ids = [
        ignore_member.member_id
        for ignore_member in database.ignored_global_members
        if ignore_member.member_id > 0
    ]
    group_ids = [
        abs(ignore_member.member_id)
        for ignore_member in database.ignored_global_members
        if ignore_member.member_id < 0
    ]

    if not user_ids and not group_ids:
        return "📃 Ваш глобальный игнор-лист пуст"

    message = "📃 Ваш глобальный игнор-лист\n"
    return await generate_user_or_groups_list(api, message, user_ids, group_ids)


@user.on.message_handler(
    FromMe(),
    text=[
        '<prefix:service_prefix> +глоигнор [id<user_id:int>|<foo>',
        '<prefix:service_prefix> +глоигнор [club<group_id:int>|<foo>',
        '<prefix:service_prefix> +глоигнор https://vk.com/<domain>',
        '<prefix:service_prefix> +глоигнор',
    ]
)
@logger_decorator
async def add_ignored_global_member_wrapper(
        message: Message,
        domain: str = None,
        user_id: int = None,
        group_id: int = None,
        **kwargs
):
    db = Database.get_current()
    member_id = user_id if user_id else None
    if not user_id and group_id:
        member_id = -group_id

    member_ids = await get_ids_by_message(message, member_id, domain)
    if not member_ids:
        await edit_message(
            message,
            f'⚠ Необходимо указать пользователей'
        )
        return

    member_id = member_ids[0]
    if member_id == await message.api.user_id:
        await edit_message(
            message,
            f'⚠ Нельзя занести себя в игнор!'
        )
        return

    if member_id > 0:
        name = f'Пользователь  [id{member_id}|{await get_full_name_by_member_id(message.api, member_id)}]'
    else:
        name = f'Группа [club{abs(member_id)}|{await get_full_name_by_member_id(message.api, member_id)}]'

    if member_id in [
        igrored_member.member_id
        for igrored_member in db.ignored_global_members
    ]:
        await edit_message(
            message,
            f'⚠ {name} уже в списке игнорируемых'
        )
        return
    add_ignore_global_member(db, member_id)
    await edit_message(
        message,
        f'✅ {name} добавлен в глобальный игнор-лист'
    )


@user.on.message_handler(
    FromMe(),
    text=[
        '<prefix:service_prefix> -глоигнор [id<user_id:int>|<foo>',
        '<prefix:service_prefix> -глоигнор [club<group_id:int>|<foo>',
        '<prefix:service_prefix> -глоигнор https://vk.com/<domain>',
        '<prefix:service_prefix> -глоигнор',
    ]
)
@logger_decorator
async def remove_ignored_global_member_wrapper(
        message: Message,
        domain: str = None,
        user_id: int = None,
        group_id: int = None,
        **kwargs
):
    db = Database.get_current()
    member_id = user_id if user_id else None
    if not user_id and group_id:
        member_id = -group_id

    member_ids = await get_ids_by_message(message, member_id, domain)
    if not member_ids:
        await edit_message(
            message,
            f'⚠ Необходимо указать пользователей'
        )
        return

    member_id = member_ids[0]

    if member_id > 0:
        name = f'Пользователь  [id{member_id}|{await get_full_name_by_member_id(message.api, member_id)}]'
    else:
        name = f'Группа [club{abs(member_id)}|{await get_full_name_by_member_id(message.api, member_id)}]'

    if member_id not in [
        igrored_member.member_id
        for igrored_member in db.ignored_global_members
    ]:
        await edit_message(
            message,
            f'⚠ {name} не в списке игнорируемых'
        )
        return
    remove_ignore_global_member(db, member_id)
    await edit_message(
        message,
        f'✅ {name} удален из игнор-листа'
    )


@user.on.message_handler(
    FromMe(),
    text=[
        '<prefix:service_prefix> глоигнорлист',
        '<prefix:service_prefix> глоигнор лист',
    ]
)
@logger_decorator
async def show_ignore_members_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    await edit_message(
        message,
        await show_ignore_global_members(
            db,
            message.api
        )
    )



from enum import Enum

from pydantic import BaseModel, validator


class GenEnum(Enum):
    NOM = "nom"
    GEN = "gen"
    DAT = "dat"
    ACC = "acc"
    INS = "ins"
    ABL = "abl"


class RolePlayCommand(BaseModel):
    name: str
    gen: GenEnum
    formatter_man: str
    formatter_woman: str
    all_ending: str

    @validator('name')
    def to_lower_validator(cls, v: str) -> str:
        return v.lower()



from vkbottle.rule import FromMe
from vkbottle.user import Blueprint, Message

from idm_lp.database import Database
from idm_lp.idm_api import IDMAPI
from idm_lp.logger import logger_decorator
from idm_lp.utils import edit_message

user = Blueprint(
    name='set_db_blueprint'
)


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> получить бд")
@logger_decorator
async def set_db_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    try:
        new_db = db.load_from_server()
    except Exception as ex:
        await edit_message(
            message,
            f"⚠ Ошибка: {ex}"
        )
        return
    new_db.save()
    Database.set_current(new_db)
    await edit_message(
        message,
        "✅ Конфигурация успешно обновлена с сервера"
    )



import argparse
import datetime
import json
import os
import traceback

import requests
import vkbottle.api
from vkbottle.api import UserApi
from vkbottle.user import User

from idm_lp import const, timers
from idm_lp.commands import commands_bp
from idm_lp.database import Database, DatabaseError
from idm_lp.error_handlers import error_handlers_bp
from idm_lp.idm_api import IDMAPI, IDMException
from idm_lp.logger import logger, Logger, LoggerLevel
from idm_lp.utils import SemVer

parser = argparse.ArgumentParser(
    description='LP модуль позволяет работать приемнику сигналов «IDM multi» работать в любых чатах.'
)

parser.add_argument(
    '--config_path',
    type=str,
    dest="config_path",
    default="config.json",
    help='Путь до файла с конфингом'
)

parser.add_argument(
    '--base_domain',
    type=str,
    dest="base_domain",
    default="https://idmduty.ru",
    help='Базовый домен'
)
parser.add_argument(
    '--disable_startup_message',
    dest="disable_startup_message",
    action="store_const",
    const=True,
    help='Отключает приветственное сообщение'
)
parser.add_argument(
    '--use_app_data',
    dest="use_app_data",
    action="store_const",
    const=True,
    help='Использовать папку AppData/IDM (Windows).\n'
         'При использовании этой настройки AppData/IDM и config_path складываются'
)

parser.add_argument(
    '--logger_level',
    dest="logger_level",
    type=str,
    default="INFO",
    help='Уровень логирования.'
)
parser.add_argument(
    '--log_to_path',
    dest="log_to_path",
    action="store_const",
    const=True,
    help='Логи в файл'
)

parser.add_argument(
    '--enable_eval',
    dest="enable_eval",
    action="store_const",
    const=True,
    help='Разрешить eval/exec'
)
parser.add_argument(
    '--use_local_db',
    dest="use_local_db",
    action="store_const",
    const=True,
    help='Не использовать ДБ IDM'
)


@Database.add_on_save
async def clear_timers(db: Database):
    now = datetime.datetime.now()
    timers_copy = db.timers[:]
    for timer in timers_copy:
        if timer.type == timer.type.DATE:
            if timer.run_date < now:
                db.timers.remove(timer)


@Database.add_on_save
async def on_db_save(db: Database):
    api = vkbottle.api.API(tokens=db.tokens)
    const.scheduler.pause()

    timers_ids = [x.id for x in const.scheduler.get_jobs()]
    if db.auto_infection:
        if 'auto_infection_timer' not in timers_ids:
            const.scheduler.add_job(
                timers.auto_infection_timer,
                id='auto_infection_timer',
                name='Таймер на авто заражение',
                args=(api, db,),
                trigger='interval',
                seconds=db.auto_infection_interval,
                max_instances=1
            )
            await timers.auto_infection_timer(api, db)
    else:
        if 'auto_infection_timer' in timers_ids:
            const.scheduler.remove_job('auto_infection_timer')
    for timer in db.timers:
        if timer.method == timer.method.SEND_MESSAGE:
            if timer.id not in timers_ids:
                const.scheduler.add_job(
                    timers.send_message_timer,
                    **timer.scheduler_params,
                    max_instances=1,
                    args=(api, db, timer,)
                )
    db_timers_ids = ['auto_infection_timer', *[x.id.hex for x in db.timers]]
    for job in const.scheduler.get_jobs():
        if job.id not in db_timers_ids:
            const.scheduler.remove_job(job.id)
    const.scheduler.resume()


@Database.add_on_save
async def on_db_save_to_server(db: Database):
    if not const.USE_LOCAL_DB:
        await IDMAPI.get_current().save_lp_info(db.tokens[0], db.get_to_server())
        logger.info("Конфиг отправлен на сервер")


async def lp_startup():
    api = UserApi.get_current()
    if not const.DISABLE_STARTUP_MESSAGE:
        text = (
            f'[IDM LP]\n'
            f'❤ Запущена версия IDM LP {const.__version__}\n'
        )
        version_rest = requests.get(const.VERSION_REST).json()

        last_stable = SemVer(version_rest['version'])
        current = SemVer(const.__version__)

        if current < last_stable:
            text += (
                f"\n💬 Доступно обновление {version_rest['version']}\n"
                f"{version_rest['description']}"
            )
            if 'DYNO' in os.environ:
                text += (
                    "\n\nЧтобы обновить введите !с обновитьлп"
                )

        elif current > last_stable:
            text += "\n💬 Обратите внимание! Вы используете экспериментальную не стабильную версию."

        const.__author__ = version_rest['author']

        await api.messages.send(
            peer_id=await api.user_id,
            random_id=0,
            message=text
        )

    try:
        await IDMAPI.get_current().ping()
    except IDMException as ex:
        await api.messages.send(
            random_id=0,
            peer_id=await api.user_id,
            message=f"[IDM LP]\n⚠ Произошла ошибка при проверке подлинности секретного кода:\n💬 {ex}"
        )
        raise KeyboardInterrupt()


def run_lp():
    args = parser.parse_args()

    const.CONFIG_PATH = args.config_path
    const.BASE_DOMAIN = args.base_domain
    const.USE_APP_DATA = args.use_app_data if args.use_app_data else False
    const.LOG_TO_PATH = args.log_to_path if args.log_to_path else False
    const.LOGGER_LEVEL = args.logger_level
    const.ENABLE_EVAL = args.enable_eval if args.enable_eval else False
    const.USE_LOCAL_DB = args.use_local_db if args.use_local_db else False
    const.DISABLE_STARTUP_MESSAGE = args.disable_startup_message if args.disable_startup_message else False

    if isinstance(logger, Logger):
        logger.global_logger_level = LoggerLevel.get_int(const.LOGGER_LEVEL)

    logger.warning(
        f"\n\nЗапуск с параметрами:\n"
        f" -> Уровень логирования              -> {const.LOGGER_LEVEL}\n"
        f" -> Логи в файл                       -> {const.LOG_TO_PATH}\n"
        f" -> Путь до файла с конфигурацией     -> {Database.get_path()}\n"
        f" -> Использовать папку AppData/IDM    -> {const.USE_APP_DATA}\n"
        f" -> Базовый домен                     -> {const.BASE_DOMAIN}\n"
        f" -> Использовать локальную БД         -> {const.USE_LOCAL_DB}\n"
        f" -> Разрешить eval/exec               -> {const.ENABLE_EVAL}\n\n"
    )

    idm_api = IDMAPI(const.BASE_DOMAIN, const.APP_USER_AGENT)
    IDMAPI.set_current(idm_api)

    try:
        db = Database.load()
        if not const.USE_LOCAL_DB:
            db = db.load_from_server()
        Database.set_current(db)
    except DatabaseError as ex:
        logger.error(
            f"{ex.name} | {ex.description}"
        )
        exit(-1)
    except json.JSONDecodeError as ex:
        logger.error(
            f'При запуске произошла ошибка базы данных.\n'
            f'Проверьте целостность данных.\n'
            f'Строка: {ex.lineno}, столбец: {ex.colno}.'
        )
        exit(-1)
    except IDMException as ex:
        logger.error(str(ex))
        exit(-1)
    except Exception as ex:
        logger.error(f'При запуске произошла ошибка [{ex.__class__.__name__}] {ex}\n{traceback.format_exc()}')
        exit(-1)
    else:
        from idm_lp.validators import (
            alias,
            role_play_command,
            self_prefix,
            duty_prefix,
            service_prefix,
            repeater_word,
            yes_or_no
        )

        user = User(
            tokens=db.tokens,
            debug=const.LOGGER_LEVEL,
            log_to_path=const.LOG_TO_PATH
        )
        user.set_blueprints(
            *commands_bp,
            *error_handlers_bp,
        )
        const.scheduler.start()
        user.run_polling(
            auto_reload=False,
            on_startup=lp_startup,
        )



import asyncio

from vkbottle.user import Blueprint, Message

from idm_lp import rules
from idm_lp.logger import logger_decorator
from idm_lp.database import Database

user = Blueprint(
    name='delete_messages_blueprint'
)


@user.on.message_handler(rules.IgnoredMembersRule())
@logger_decorator
async def ignore_delete_message_wrapper(message: Message):
    await message.api.messages.delete(
        message_ids=[message.id]
    )


@user.on.message_handler(rules.IgnoredGlobalMembersRule())
@logger_decorator
async def ignore_delete_message_wrapper(message: Message):
    await message.api.messages.delete(
        message_ids=[message.id]
    )


@user.on.message_handler(rules.MutedMembersRule())
@logger_decorator
async def muted_delete_message_wrapper(message: Message):
    db = Database.get_current()
    for muted_member in db.muted_members:
        if muted_member.chat_id == message.peer_id and muted_member.member_id == message.from_id:
            if muted_member.delay:
                await asyncio.sleep(muted_member.delay)
            await message.api.messages.delete(
                message_ids=[message.id],
                delete_for_all=True
            )



import traceback

from vkbottle.framework.framework.rule import FromMe
from vkbottle.user import Blueprint, Message

from idm_lp import const
from idm_lp.logger import logger_decorator
from idm_lp.database import Database
from idm_lp.utils import edit_message

user = Blueprint(
    name='run_eval_blueprint'
)


@user.on.message_handler(FromMe(), text='<prefix:service_prefix> eval <signal>')
@logger_decorator
async def eval_signal_wrapper(message: Message, signal: str, **kwargs):
    if not const.ENABLE_EVAL:
        return
    db = Database.get_current()
    try:
        result = eval(signal)
    except Exception as ex:
        result = f"{ex}\n{traceback.format_exc()}"

    if not result:
        result = '✅ Выполнено'

    await edit_message(
        message,
        result
    )


@user.on.message_handler(FromMe(), text='<prefix:service_prefix> exec <signal>', lower=True)
@logger_decorator
async def exec_signal_wrapper(message: Message, signal: str, **kwargs):
    if not const.ENABLE_EVAL:
        return
    db = Database.get_current()
    try:
        result = exec(signal)
    except Exception as ex:
        result = f"{ex}\n{traceback.format_exc()}"

    if not result:
        result = '✅ Выполнено'

    await edit_message(
        message,
        result
    )



from typing import List, Dict

import requests
from vkbottle.rule import FromMe
from vkbottle.user import Blueprint, Message

from idm_lp import const
from idm_lp.logger import logger, logger_decorator
from idm_lp.database import Database, Alias
from idm_lp.utils import edit_message

user = Blueprint(
    name='aliases_manager_blueprint'
)


def add_alias(database: Database, name: str, command_from: str, command_to: str) -> Alias:
    new_alias = Alias(**{
        'name': name,
        'command_from': command_from,
        'command_to': command_to
    })
    database.aliases.append(new_alias)
    database.save()
    return new_alias


def remove_alias(database: Database, alias: Alias) -> None:
    database.aliases.remove(alias)
    database.save()


def show_aliases(database: Database) -> str:
    if len(database.aliases):
        message = '📃 Ваши алиасы:\n'
        index = 1
        for alias in database.aliases:
            message += f"{index}. {alias.name} ({alias.command_from} -> !л {alias.command_to})\n"
            index += 1
        return message
    else:
        return "⚠ У вас нет алиасов"


def delete_last_space(value: str) -> str:
    if value[-1] == ' ':
        return value[:-1]
    return value


@user.on.message_handler(
    FromMe(),
    text="<prefix:service_prefix> +алиас <alias_name:lower_str>\n<command_from>\n<command_to>"
)
@logger_decorator
async def add_alias_wrapper(message: Message, alias_name: str, command_from: str, command_to: str, *args, **kwargs):
    db = Database.get_current()
    logger.info(f"Создание алиаса\n")
    alias_name = delete_last_space(alias_name)
    command_from = delete_last_space(command_from)
    command_to = delete_last_space(command_to)

    for alias in db.aliases:
        if alias_name == alias.name:
            await edit_message(
                message,
                f"⚠ Алиас <<{alias_name}>> уже существует"
            )
            return

    new_alias = add_alias(db, alias_name, command_from, command_to)
    await edit_message(
        message,
        f"✅ Новый алиас <<{alias_name}>> создан\n"
        f"Команды: {new_alias.command_from} -> !л {command_to}"
    )


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> алиасы")
@logger_decorator
async def show_aliases_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    logger.info(f"Просмотр алиасов\n")
    await edit_message(
        message,
        show_aliases(db)
    )


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> -алиас <alias_name:lower_str>")
@logger_decorator
async def remove_alias_wrapper(message: Message, alias_name: str, **kwargs):
    db = Database.get_current()
    logger.info(f"Удаление алиаса\n")
    alias_name = delete_last_space(alias_name)
    for alias in db.aliases:
        if alias_name == alias.name:
            remove_alias(db, alias)
            await edit_message(
                message,
                f"✅ Алиас <<{alias_name}>> удален"
            )
            return

    await edit_message(
        message,
        f'⚠ Алиас <<{alias_name}>> не найден'
    )


def get_alias_packs() -> Dict[str, List[Alias]]:
    data = requests.get(const.ALIASES_REST).json()
    packs = {}
    for key in data.keys():
        packs.update({
            key: [
                Alias(**dict_alias) for dict_alias in data[key]
            ]
        })
    return packs


def generate_aliases_pack_description(pack: List[Alias]) -> str:
    message = ""
    index = 1
    for alias in pack:
        message += f"{index}. {alias.name} ({alias.command_from} -> !л {alias.command_to})\n"
        index += 1
    return message


def check_name_duplicates(db: Database, pack: List[Alias]) -> bool:
    current_alias_names = [alias.name for alias in db.aliases]
    for alias in pack:
        if alias.name in current_alias_names:
            return False
    return True


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> алиасы импорт <pack_name>")
@logger_decorator
async def import_aliases_wrapper(message: Message, pack_name: str, **kwargs):
    db = Database.get_current()
    alias_packs = get_alias_packs()
    if pack_name not in alias_packs.keys():
        await edit_message(
            message,
            "⚠ Пак не найден"
        )
        return

    logger.info(f"Импорт алиасов\n")
    pack = alias_packs[pack_name]

    if not check_name_duplicates(db, pack):
        await edit_message(
            message,
            "⚠ Не удалось импортировать пак. Есть дубликаты."
        )
        return

    db.aliases.extend(pack)
    db.save()
    await edit_message(
        message,
        f"Импортированно {len(pack)} алиасов\n" + generate_aliases_pack_description(pack)
    )


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> алиасы паки")
@logger_decorator
async def import_aliases_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    alias_packs = get_alias_packs()
    text = "📃 Паки алиасов:\n"
    index = 1
    for pack_name in alias_packs.keys():
        text += f"{index}. {pack_name} ({len(alias_packs[pack_name])} алиасов)\n"
        index += 1
    await edit_message(
        message,
        text
    )


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> алиасы пак <pack_name>")
@logger_decorator
async def import_aliases_wrapper(message: Message, pack_name: str, **kwargs):
    db = Database.get_current()
    alias_packs = get_alias_packs()
    if pack_name not in alias_packs.keys():
        await edit_message(
            message,
            "⚠ Пак не найден"
        )
        return
    pack = alias_packs[pack_name]
    await edit_message(
        message,
        f"Пак алиасов <<{pack_name}>>:\n" +
        generate_aliases_pack_description(pack)
    )



import datetime

from vkbottle.framework.framework.rule import FromMe
from vkbottle.user import Blueprint, Message

from idm_lp.logger import logger_decorator
from idm_lp.database import Database
from idm_lp.utils import edit_message

user = Blueprint(
    name='delete_messages_vks_blueprint'
)

DD_SCRIPT = (
    'var i = 0;var msg_ids = [];var count = %d;'
    'var items = API.messages.getHistory({"peer_id":%d,"count":"200", "offset":"0"}).items;'
    'while (count > 0 && i < items.length) {if (items[i].out == 1) {if (items[i].id == %d) {'
    'if (items[i].reply_message) {msg_ids.push(items[i].id);msg_ids.push(items[i].reply_message.id);'
    'count = 0;};if (items[i].fwd_messages) {msg_ids.push(items[i].id);var j = 0;while (j < '
    'items[i].fwd_messages.length) {msg_ids.push(items[i].fwd_messages[j].id);j = j + 1;};count = 0;};};'
    'msg_ids.push(items[i].id);count = count - 1;};if ((%d - items[i].date) > 86400) {count = 0;};i = i + 1;};'
    'API.messages.delete({"message_ids": msg_ids,"delete_for_all":"1"});return count;'
)


@user.on.message_handler(
    FromMe(),
    text=["<count:dd_value>", "<s:dd_prefix>"],
)
@logger_decorator
async def dd_handler(message: Message, count: int = 1, **kwargs):
    count += 1
    await message.api.execute(
        DD_SCRIPT % (
            count,
            message.peer_id,
            message.from_id,
            int(datetime.datetime.now().timestamp())
        )
    )


@user.on.message_handler(
    FromMe(),
    text=["<s:dd_prefix> все", "<s:dd_prefix> всё"],
)
@logger_decorator
async def dd_all_handler(message: Message, **kwargs):
    count = 1000
    await message.api.execute(
        DD_SCRIPT % (
            count,
            message.peer_id,
            message.from_id,
            int(datetime.datetime.now().timestamp())
        )
    )


@user.on.message_handler(
    FromMe(),
    text="<s:service_prefix> дд префикс <prefix>",
)
@logger_decorator
async def set_dd_prefix_handler(message: Message, prefix: str, **kwargs):
    db = Database.get_current()
    db.dd_prefix = prefix
    db.save()
    await edit_message(
        message,
        f"✅ Префикс дд установлен на <<{db.dd_prefix}>>"
    )



import typing

import aiohttp
import requests
from vkbottle.api import UserApi

from idm_lp.logger import logger
from idm_lp.database import ContextInstanceMixin, Database


class IDMException(Exception):
    ...


class IDMAPIException(IDMException):

    def __init__(self, code, detail, **kw):
        self.code = code
        self.detail = detail
        self.kwargs = kw

    def __str__(self):
        return f"[{self.code}] {self.detail}"


class IDMAPICallbackException(IDMException):
    CALLBACK_CODES = {
        1: "Пустой запрос",
        2: "Неизвестный тип сигнала",
        3: "Пара пользователь/секрет не найдены",
        4: "Беседа не привязана",
        5: "Пользователь заблокирован",
        6: "Дежурный не активен",
        7: "Пользователь не активен",
        10: "Не удалось связать беседу"
    }

    def __init__(
            self,
            response: str,
            error_code: typing.Optional[int] = None,
            error_message: typing.Optional[str] = None,
            **kw
    ):
        self.error_type = response
        self.error_code = error_code
        self.error_message = error_message
        self.kwargs = kw

    def __str__(self):
        if self.error_type == 'error':
            if self.error_code in self.CALLBACK_CODES:
                return f"[{self.error_code}] {self.CALLBACK_CODES[self.error_code]}"
            elif self.error_message:
                return f"[{self.error_code}] {self.error_message}"
            else:
                return f"[{self.error_code}] Нe известная ошибка"
        else:
            if self.error_message:
                return f"VK [{self.error_code}] {self.error_message}"
            else:
                return f"VK [{self.error_code}] Нe известная ошибка"


class IDMAPI(ContextInstanceMixin):
    _session: typing.Optional[aiohttp.ClientSession]
    _sync_session: typing.Optional[requests.Session]

    def __init__(self, base_domain: str, header: str):
        self.base_domain = base_domain
        self.header_info = header
        self._session = None
        self._sync_session = None

        self._get_lp_info_link = f"{self.base_domain}/api/dutys/get_lp_info/"
        self._save_lp_info_link = f"{self.base_domain}/api/dutys/save_lp_info/"
        self._callback_link = f"{self.base_domain}/callback/"

    @property
    def sync_session(self) -> requests.Session:
        if not self._sync_session:
            self._sync_session = requests.Session()
        return self._sync_session

    @property
    def session(self):
        if not self._session or self._session.closed:
            self._session = aiohttp.ClientSession(headers={"User-Agent": self.header_info})
        return self._session

    def get_lp_info_sync(self, access_token: str) -> dict:
        response = self.sync_session.post(
            self._get_lp_info_link,
            json={'access_token': access_token},
            headers={'User-Agent': self.header_info}
        ).json()
        if 'error' in response:
            raise IDMAPIException(**response['error'])
        return response['response']

    async def send_request(self, url: str, data: dict) -> dict:
        logger.debug(f"Send POST request to {url} with data {data!r}")
        async with self.session.post(url, json=data) as response:
            response_json = await response.json()
            logger.debug(f"Response from {url}: {response_json!r}")

            if 'error' in response_json:
                raise IDMAPIException(**response_json['error'])
            if response_json['response'] in ('error', 'vk_error',):
                raise IDMAPICallbackException(**response_json)
            return response_json

    async def get_lp_info(self, access_token: str):
        response = await self.send_request(self._get_lp_info_link, {'access_token': access_token})
        return response['response']

    async def save_lp_info(self, access_token: str, database: dict):
        response = await self.send_request(self._save_lp_info_link, {
            'access_token': access_token,
            'config': database
        })
        return response['response']

    async def callback(self, data: dict) -> dict:
        api = UserApi.get_current()
        db = Database.get_current()

        data['user_id'] = await api.user_id
        data['secret'] = db.secret_code

        return await self.send_request(self._callback_link, data)

    async def ping(self):
        return await self.callback({
            "method": "ping",
            "message": {},
            "object": {}
        })

    async def _send_signal(
            self,
            method: str,
            from_id: int,
            peer_id: int,
            conversation_message_id: int,
            date: int,
            text: str,
            vk_message: typing.Optional[dict] = None
    ):
        return await self.callback({
            "method": method,
            "message": {
                "conversation_message_id": conversation_message_id,
                "from_id": from_id,
                "date": date,
                "text": text,
                "peer_id": peer_id
            },
            "object": {
                "chat": None,
                "from_id": from_id,
                "value": text,
                "conversation_message_id": conversation_message_id
            },
            "vkmessage": vk_message
        })

    async def send_my_signal(
            self,
            from_id: int,
            peer_id: int,
            conversation_message_id: int,
            date: int,
            text: str,
            vk_message: typing.Optional[dict] = None
    ):
        return await self._send_signal(
            'lpSendMySignal',
            from_id=from_id, peer_id=peer_id,
            conversation_message_id=conversation_message_id,
            date=date, text=text, vk_message=vk_message
        )

    async def send_signal(
            self,
            from_id: int,
            peer_id: int,
            conversation_message_id: int,
            date: int,
            text: str,
            vk_message: typing.Optional[dict] = None
    ):
        return await self._send_signal(
            'lpSendSignal',
            from_id=from_id, peer_id=peer_id,
            conversation_message_id=conversation_message_id,
            date=date, text=text, vk_message=vk_message
        )



from pydantic import BaseModel, validator


class RegexDeleter(BaseModel):
    name: str
    regex: str
    chat_id: int
    for_all: bool = False

    @validator('name')
    def to_lower_validator(cls, v: str) -> str:
        return v.lower()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['idm_lp',
 'idm_lp.commands',
 'idm_lp.commands.members_manager',
 'idm_lp.database',
 'idm_lp.error_handlers']

package_data = \
{'': ['*']}

install_requires = \
['APScheduler>=3.9.1,<4.0',
 'pydantic>=1.7.3,<2.0',
 'python-rucaptcha>=3.0,<4.0',
 'vkbottle>=2.7.12,<3.0.0']

setup_kwargs = {
    'name': 'idm-lp',
    'version': '1.15.6',
    'description': 'LP модуль позволяет работать приемнику сигналов «IDM» работать в любых чатах.',
    'long_description': '### IDM LP\n![PyPI](https://img.shields.io/pypi/v/idm-lp)\n![GitHub](https://img.shields.io/github/license/IDM-Team/idm_lp)\n![GitHub repo size](https://img.shields.io/github/repo-size/IDM-Team/idm_lp)\n[![Downloads](https://pepy.tech/badge/idm-lp)](https://pepy.tech/project/idm-lp)\n\nLP модуль позволяет работать приемнику сигналов «IDM» работать в любых чатах.\n\n<!--\n4: 252535322122234232\n  1  2  3  4  5\n1 a  b  c  d  e\n2 f  g  h  ij k\n3 l  m  n  o  p\n4 q  r  s  y  u\n5 v  w  x  y  z\n-->\n\n## Оглавление\n1. [Установка](#установка)\n2. [Аргументы запуска](#аргументы-запуска)\n3. [Структура конфигурационного файла config.json](#структура-кофигурационного-файла-configjson)\n4. [Команды модуля ЛП](#команды-модуля-лп)\n\n## Установка\n\nСуществует 2 вида установки:\n1. [Деплой на Heroku](https://github.com/IDM-Team/idm_lp/blob/heroku-deploy/README.md)\n2. [Установка на свое устройство](https://github.com/IDM-Team/idm_lp/blob/self-system-install/README.md)\n\n\n## Аргументы запуска \n- `--logger_level [DEBUG | INFO | WARNING | ERROR | CRITICAL]` — уровень логирования\n- `--config_path CONFIG_PATH` — путь до файла с конфигурацией\n- `--use_app_data` — использовать папку AppData/IDM (Windows). При использовании этой настройки AppData/IDM и config_path складываются\n- `--log_to_path` — логи в файл\n- `--base_domain BASE_DOMAIN` — базовый домен\n- `--use_local_db` — не использовать конфигурационный файл с сервера IDM\n- `--disable_startup_message` — отключить приветственное сообщение\n\n## Структура конфигурационного файла config.json\n- `tokens`            - Токены вк в количестве 3х штук. Получить можно [здесь](https://oauth.vk.com/authorize?client_id=2685278&scope=1073737727&redirect_uri=https://oauth.vk.com/blank.html&display=page&response_type=token&revoke=1)\n- `service_prefixes`  - Префиксы для выполнения команд модуля ЛП (добавление в мутлист, создание алиасов и тд.)\n\n## Команды модуля ЛП\n- `{сервисный префикс}` пинг/кинг/пиу — пинг\n- `{сервисный префикс}` инфо — информация о модуле ЛП\n***\n- `{сервисный префикс}` префиксы свои — просмотр своих префиксов\n- `{сервисный префикс}` префиксы дежурный — просмотр префиксов для дежурного\n- `{сервисный префикс}` +префикс `[свой/дежурный]` — создание префикса\n- `{сервисный префикс}` -префикс `[свой/дежурный]` — удаление префикса\n***\n- `{сервисный префикс}` алиасы - просмотр алиасов\n- `{сервисный префикс}` +алиас `{имя}` {enter} `{команда которую получает модуль ЛП}` {enter} `{команда которую отсылает модуль ЛП}`  — создание алиаса\n- `{сервисный префикс}` -алиас `{имя}` — удаление алиаса\n- `{сервисный префикс}` алиасы паки — просмотр паков алиасов\n- `{сервисный префикс}` алиасы пак `{имя пака}` — просмотр пака алиасов\n- `{сервисный префикс}` алиасы импорт `{имя пака}` — импорт пака алиасов\n***\n- `{сервисный префикс}` игнорлист — просмотр игнорлиста\n- `{сервисный префикс}` игнорлист все — просмотр игнорлиста по всем чатам\n- `{сервисный префикс}` +игнор `[{ссылка}/{упоминание}/{реплай}]` — добавить в игнорлист\n- `{сервисный префикс}` -игнор `[{ссылка}/{упоминание}/{реплай}]` — удалить из игнорлиста\n***\n- `{сервисный префикс}` глоигнорлист — просмотр глоигнорлиста\n- `{сервисный префикс}` +глоигнор `[{ссылка}/{упоминание}/{реплай}]` — добавить в глоигнорлист\n- `{сервисный префикс}` -глоигнор `[{ссылка}/{упоминание}/{реплай}]` — удалить из глоигнорлиста\n***\n- `{сервисный префикс}` мутлист — просмотр мутлиста\n- `{сервисный префикс}` мутлист все — просмотр мутлиста по всем чатам\n- `{сервисный префикс}` +мут `[{ссылка}/{упоминание}/{реплай}]` `{задержка}` — добавить в мутлист\n- `{сервисный префикс}` -мут `[{ссылка}/{упоминание}/{реплай}]` — удалить из мутлиста\n***\n- `{сервисный префикс}` довы — просмотр доверенных пользователей\n- `{сервисный префикс}` +дов `[{ссылка}/{упоминание}/{реплай}]` — добавить в дов-лист\n- `{сервисный префикс}` -дов `[{ссылка}/{упоминание}/{реплай}]` — удалить из дов-листа\n***\n- `{сервисный префикс}` regex — Просмотр шаблонов для удаления\n- `{сервисный префикс}` +regex `{имя}` `{regex}` `{для всех:да|нет}` — Добавить шаблон\n- `{сервисный префикс}` -regex `{имя}` — Удалить шаблон\n***\n- `{сервисный префикс}` +потворялка — включить повторялку\n- `{сервисный префикс}` -потворялка — выключить повторялку\n- `{триггер повторялки}``{сообщение}` — повторить сообщение\n***\n- `{сервисный префикс}` eval/exec `{script}` — выполнение скрипта\n***\n- `{сервисный префикс}` -уведы — модуль будет удалять упоминания типа `@all`, `@online`...\n- `{сервисный префикс}` +уведы — не будет удалять упоминания типа `@all`, `@online`...\n***\n- `{сервисный префикс}` рп — просмотр РП команд\n- `{сервисный префикс}` +мрп `{имя}` `{падеж}`\\n`{форматер для мужчин}`\\n`{форматер для женщин}`\\n`{окончание для всех}` — просмотр РП команд\n- `{сервисный префикс}` -мрп `{имя}` — просмотр РП команд\n***\n- `{сервисный префикс}` секретный код `{код}` — установка секретного кода\n- `{сервисный префикс}` токен каптчи `{токен}` — установка токена рукаптчи\n***\n- `{сервисный префикс}` +автовыход — включить автовыход из бесед в которые вас пригласили\n- `{сервисный префикс}` -автовыход — выключить автовыход из бесед в которые вас пригласили\n- `{сервисный префикс}` автовыход +удаление — удалять диалог при выходе\n- `{сервисный префикс}` автовыход -удаление — неудалять диалог при выходе\n- `{сервисный префикс}` автовыход +чс — включить добавление в ЧС пригласившего \n- `{сервисный префикс}` автовыход -чс — выключить добавление в ЧС пригласившего\n***\n- `{сервисный префикс}` +добавление `{текст}` — включить отправку запросов в друзья, пользователям, которые заходят в чат. При этом будет отправляться приветственный `{текст}`.\n- `{сервисный префикс}` -добавление — отключить отправку запросов в друзья, пользователям, которые заходят в чат.\n***\n- `{сервисный префикс}` выключать уведы — включить выключение уведомлений при входе в беседу \n- `{сервисный префикс}` не выключать уведы — выключить выключение уведомлений при входе в беседу \n***\n[Предупреждение](https://vk.com/wall-174105461_15842772)\n\nМетоды можно включить раскомментировав \n`auto_infection.user,`\n`bio_wars.user,`\n\n\n- ~~`{сервисный префикс}` +заражение — включить ответное заражение.~~\n- ~~`{сервисный префикс}` -заражение — отключить ответное заражение.~~\n***\n- ~~`{сервисный префикс}` +автозаражение — включить автоматическое.~~\n- ~~`{сервисный префикс}` -автозаражение — отключить автоматическое.~~\n- ~~`{сервисный префикс}` автозаражение интервал `{интервал}` — установить интервал автоматического заражения.~~\n- ~~`{сервисный префикс}` автозаражение аргумент `{аргумент}` — установить аргумент автоматического заражения.~~\n- ~~`{сервисный префикс}` автозаражение установить чат — установить чат автоматического заражения.~~\n- ~~`{сервисный префикс}` автозаражение — информация об автоматическом заражении.~~\n***\n- ~~`{сервисный префикс}` +автовакцина — включение автовакцины~~\n- ~~`{сервисный префикс}` -автовакцина — выключение автовакцины~~\n***\n- `{сервисный префикс}` +nometa — включить nometa.\n- `{сервисный префикс}` -nometa — отключить nometa.\n- `{сервисный префикс}` nometa сообщение `{текст}` — изменить текст сообщения.\n- `{сервисный префикс}` nometa задержка `{задержка}` — изменить задержку.\n***\n- `{сервисный префикс}` получить бд — получить бд с сервера IDM\n***\n- `{сервисный префикс}` таймеры — показать текущие таймеры\n- `{сервисный префикс}` !таймеры — показать текущие таймеры загруженные в планировщике задач\n- `{сервисный префикс}` +таймер `{имя таймера}` смс `{время}`\\n`текст сообщения` — создание таймера, который сработает в определенное время\n- `{сервисный префикс}` +цтаймер `{имя таймера}` смс `{интервал}`\\n`текст сообщения` — создание циклического таймера\n- `{сервисный префикс}` +ктаймер `{имя таймера}` смс `{CRON}`\\n`текст сообщения` — создание таймера, который сработает по CRON выражению\n- `{сервисный префикс}` -таймер `{имя таймера}` — удаление таймера\n',
    'author': 'lordralinc',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://idmduty.ru',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



from vbml.blanket import validator
from idm_lp.database import Database

__all__ = (
    'alias',
    'role_play_command',
    'self_prefix',
    'duty_prefix',
    'service_prefix',
    'repeater_word',
    'yes_or_no'
)


@validator
def alias(value: str):
    db = Database.get_current()
    for alias_ in db.aliases:
        if value.lower() == alias_.command_from:
            return alias_


@validator
def role_play_command(value: str):
    db = Database.get_current()
    for rp_cmd in db.role_play_commands:
        if value.lower() == rp_cmd.name.lower():
            return rp_cmd


@validator
def self_prefix(value: str):
    db = Database.get_current()
    if value.lower() in db.self_prefixes:
        return value


@validator
def dd_prefix(value: str):
    db = Database.get_current()
    if value.lower() in db.dd_prefix:
        return value


@validator
def dd_value(value: str):
    db = Database.get_current()
    if db.dd_prefix in value.lower():
        try:
            return int(value.lower().replace(db.dd_prefix, ''))
        except ValueError:
            ...


@validator
def duty_prefix(value: str):
    db = Database.get_current()
    if value.lower() in db.duty_prefixes:
        return value


@validator
def service_prefix(value: str):
    db = Database.get_current()
    if value.lower() in db.service_prefixes:
        return value


@validator
def lower_str(value: str):
    return value.lower()


@validator
def repeater_word(value: str):
    db = Database.get_current()
    if value.startswith(db.repeater_word):
        return value.replace(db.repeater_word, '', 1)


@validator
def yes_or_no(value: str):
    if value in ('да', '+', '1'):
        return True
    elif value in ('нет', '-', '0'):
        return False



from vkbottle.framework.framework.rule import FromMe
from vkbottle.user import Blueprint, Message

from idm_lp.logger import logger_decorator
from idm_lp.database import Database
from idm_lp.utils import edit_message

user = Blueprint(
    name='set_secret_code_blueprint'
)


@user.on.message(FromMe(), text='<prefix:service_prefix> секретный код <secret_code>')
@logger_decorator
async def set_secret_code_wrapper(message: Message, secret_code: str, **kwargs):
    with Database.get_current() as db:
        db.secret_code = secret_code
    await edit_message(
        message,
        "✅ Секретный код установлен"
    )


@user.on.message(FromMe(), text='<prefix:service_prefix> токен каптчи <secret_code>')
@logger_decorator
async def set_secret_code_wrapper(message: Message, ru_captcha_key: str, **kwargs):
    with Database.get_current() as db:
        db.ru_captcha_key = ru_captcha_key
    await edit_message(
        message,
        "✅ Токен каптчи установлен"
    )



import json

from vkbottle.rule import FromMe
from vkbottle.user import Blueprint, Message

from idm_lp.idm_api import IDMAPI, IDMException
from idm_lp.logger import logger_decorator

user = Blueprint(
    name='self_signal_blueprint'
)


@user.on.message_handler(FromMe(), text='<prefix:self_prefix> <signal>')
@logger_decorator
async def self_signal(message: Message, prefix: str, signal: str):
    try:
        await IDMAPI.get_current().send_my_signal(
            from_id=message.from_id, peer_id=message.peer_id,
            conversation_message_id=message.conversation_message_id,
            date=message.date, text=prefix + ' ' + signal, vk_message=json.loads(message.json())
        )
    except IDMException as ex:
        await message.api.messages.send(
            random_id=0,
            peer_id=await message.api.user_id,
            message=f"[IDM LP]\n⚠ Произошла ошибка при отправке сигнала на сервер IDM:\n💬 {ex}"
        )



from vkbottle.framework.framework.rule import FromMe
from vkbottle.user import Blueprint, Message

from idm_lp.logger import logger_decorator
from idm_lp.database import Database
from idm_lp.rules import TrustedRule
from idm_lp.utils import edit_message

user = Blueprint(
    name='repeat_blueprint'
)


@user.on.message_handler(TrustedRule(), text='<signal:repeater_word>')
@logger_decorator
async def repeat_wrapper(message: Message, signal: str, **kwargs):
    db = Database.get_current()
    if not db.repeater_active:
        return
    return signal


@user.on.message_handler(FromMe(), text='<prefix:service_prefix> +повторялка')
@logger_decorator
async def repeat_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    db.repeater_active = True
    db.save()
    await edit_message(message, "✅ Повторялка включена")


@user.on.message_handler(FromMe(), text='<prefix:service_prefix> -повторялка')
@logger_decorator
async def repeat_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    db.repeater_active = False
    db.save()
    await edit_message(message, "✅ Повторялка выключена")


@user.on.message_handler(FromMe(), text='<prefix:service_prefix> повторялка <text:lower_str>')
@logger_decorator
async def repeat_wrapper(message: Message, text: str, **kwargs):
    db = Database.get_current()
    db.repeater_word = text
    db.save()
    await edit_message(message, f"✅ Префикс повторялки установлен на <<{text}>>")
